==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashFluent<A extends LoadBalancerSettingsConsistentHashFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashFluent() {
  }
  public LoadBalancerSettingsConsistentHashFluent(LoadBalancerSettingsConsistentHash instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHash());

    if (instance != null) {
      this.withConsistentHash(instance.getConsistentHash());
      this.withConsistentHash(instance.getConsistentHash());
    }
  }
  private LoadBalancerSettingsConsistentHashLBBuilder consistentHash;
  public LoadBalancerSettingsConsistentHashLB buildConsistentHash() {
    return this.consistentHash!=null ?this.consistentHash.build():null;
  }
  public A withConsistentHash(LoadBalancerSettingsConsistentHashLB consistentHash) {
    _visitables.get("consistentHash").remove(this.consistentHash);
    if (consistentHash!=null){ this.consistentHash= new LoadBalancerSettingsConsistentHashLBBuilder(consistentHash); _visitables.get("consistentHash").add(this.consistentHash);} else { this.consistentHash = null; _visitables.get("consistentHash").remove(this.consistentHash); } return (A) this;
  }
  public boolean hasConsistentHash() {
    return this.consistentHash != null;
  }
  public ConsistentHashNested<A> withNewConsistentHash() {
    return new ConsistentHashNested(null);
  }
  public ConsistentHashNested<A> withNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return new ConsistentHashNested(item);
  }
  public ConsistentHashNested<A> editConsistentHash() {
    return withNewConsistentHashLike(java.util.Optional.ofNullable(buildConsistentHash()).orElse(null));
  }
  public ConsistentHashNested<A> editOrNewConsistentHash() {
    return withNewConsistentHashLike(java.util.Optional.ofNullable(buildConsistentHash()).orElse(new LoadBalancerSettingsConsistentHashLBBuilder().build()));
  }
  public ConsistentHashNested<A> editOrNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return withNewConsistentHashLike(java.util.Optional.ofNullable(buildConsistentHash()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashFluent that = (LoadBalancerSettingsConsistentHashFluent) o;
    if (!java.util.Objects.equals(consistentHash, that.consistentHash)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(consistentHash,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (consistentHash != null) { sb.append("consistentHash:"); sb.append(consistentHash); }
    sb.append("}");
    return sb.toString();
  }
  public class ConsistentHashNested<N> extends LoadBalancerSettingsConsistentHashLBFluent<ConsistentHashNested<N>> implements Nested<N>{
    ConsistentHashNested(LoadBalancerSettingsConsistentHashLB item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashFluent.this.withConsistentHash(builder.build());
    }
    public N endConsistentHash() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsConsistentHashFluent<A extends LoadBalancerSettingsConsistentHashFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashFluent() {
  }
  
  public LoadBalancerSettingsConsistentHashFluent(LoadBalancerSettingsConsistentHash instance) {
    this.copyInstance(instance);
  }
  private LoadBalancerSettingsConsistentHashLBBuilder consistentHash;
  
  protected void copyInstance(LoadBalancerSettingsConsistentHash instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHash());
  
    if (instance != null) {
        this.withConsistentHash(instance.getConsistentHash());
        this.withConsistentHash(instance.getConsistentHash());
      }
  }
  
  public LoadBalancerSettingsConsistentHashLB buildConsistentHash() {
    return this.consistentHash!=null ?this.consistentHash.build():null;
  }
  
  public A withConsistentHash(LoadBalancerSettingsConsistentHashLB consistentHash) {
    _visitables.get("consistentHash").remove(this.consistentHash);
    if (consistentHash!=null){ this.consistentHash= new LoadBalancerSettingsConsistentHashLBBuilder(consistentHash); _visitables.get("consistentHash").add(this.consistentHash);} else { this.consistentHash = null; _visitables.get("consistentHash").remove(this.consistentHash); } return (A) this;
  }
  
  public boolean hasConsistentHash() {
    return this.consistentHash != null;
  }
  
  public ConsistentHashNested<A> withNewConsistentHash() {
    return new ConsistentHashNested(null);
  }
  
  public ConsistentHashNested<A> withNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return new ConsistentHashNested(item);
  }
  
  public ConsistentHashNested<A> editConsistentHash() {
    return withNewConsistentHashLike(java.util.Optional.ofNullable(buildConsistentHash()).orElse(null));
  }
  
  public ConsistentHashNested<A> editOrNewConsistentHash() {
    return withNewConsistentHashLike(java.util.Optional.ofNullable(buildConsistentHash()).orElse(new LoadBalancerSettingsConsistentHashLBBuilder().build()));
  }
  
  public ConsistentHashNested<A> editOrNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return withNewConsistentHashLike(java.util.Optional.ofNullable(buildConsistentHash()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashFluent that = (LoadBalancerSettingsConsistentHashFluent) o;
    if (!java.util.Objects.equals(consistentHash, that.consistentHash)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(consistentHash,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (consistentHash != null) { sb.append("consistentHash:"); sb.append(consistentHash); }
    sb.append("}");
    return sb.toString();
  }
  public class ConsistentHashNested<N> extends LoadBalancerSettingsConsistentHashLBFluent<ConsistentHashNested<N>> implements Nested<N>{
    ConsistentHashNested(LoadBalancerSettingsConsistentHashLB item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashFluent.this.withConsistentHash(builder.build());
    }
    
    public N endConsistentHash() {
      return and();
    }
    
  
  }

}
